# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: angzarr/command_handler.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'angzarr/command_handler.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.angzarr import types_pb2 as angzarr_dot_types__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from angzarr_client.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ngzarr/command_handler.proto\x12\x07\x61ngzarr\x1a\x13\x61ngzarr/types.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\"s\n\rReplayRequest\x12\x36\n\rbase_snapshot\x18\x01 \x01(\x0b\x32\x11.angzarr.SnapshotR\x0c\x62\x61seSnapshot\x12*\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x12.angzarr.EventPageR\x06\x65vents\"<\n\x0eReplayResponse\x12*\n\x05state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x05state\"\xb2\x01\n\x0f\x43ommandResponse\x12*\n\x06\x65vents\x18\x01 \x01(\x0b\x32\x12.angzarr.EventBookR\x06\x65vents\x12\x35\n\x0bprojections\x18\x02 \x03(\x0b\x32\x13.angzarr.ProjectionR\x0bprojections\x12<\n\x0e\x63\x61scade_errors\x18\x03 \x03(\x0b\x32\x15.angzarr.CascadeErrorR\rcascadeErrors\"\xa6\x01\n\x0c\x43\x61scadeError\x12%\n\x0e\x63omponent_name\x18\x01 \x01(\tR\rcomponentName\x12%\n\x0e\x63omponent_type\x18\x02 \x01(\tR\rcomponentType\x12#\n\rerror_message\x18\x03 \x01(\tR\x0c\x65rrorMessage\x12#\n\rsource_domain\x18\x04 \x01(\tR\x0csourceDomain\"\xce\x01\n\x12RevocationResponse\x12\x34\n\x16\x65mit_system_revocation\x18\x01 \x01(\x08R\x14\x65mitSystemRevocation\x12\x38\n\x19send_to_dead_letter_queue\x18\x02 \x01(\x08R\x15sendToDeadLetterQueue\x12\x1a\n\x08\x65scalate\x18\x03 \x01(\x08R\x08\x65scalate\x12\x14\n\x05\x61\x62ort\x18\x04 \x01(\x08R\x05\x61\x62ort\x12\x16\n\x06reason\x18\x05 \x01(\tR\x06reason\"\xc6\x01\n\x10\x42usinessResponse\x12,\n\x06\x65vents\x18\x01 \x01(\x0b\x32\x12.angzarr.EventBookH\x00R\x06\x65vents\x12=\n\nrevocation\x18\x02 \x01(\x0b\x32\x1b.angzarr.RevocationResponseH\x00R\nrevocation\x12;\n\x0cnotification\x18\x03 \x01(\x0b\x32\x15.angzarr.NotificationH\x00R\x0cnotificationB\x08\n\x06result\"\x8c\x01\n\x1eSpeculateCommandHandlerRequest\x12.\n\x07\x63ommand\x18\x01 \x01(\x0b\x32\x14.angzarr.CommandBookR\x07\x63ommand\x12:\n\rpoint_in_time\x18\x02 \x01(\x0b\x32\x16.angzarr.TemporalQueryR\x0bpointInTime\"\xa7\x01\n\x15\x46\x61\x63tInjectionResponse\x12*\n\x06\x65vents\x18\x01 \x01(\x0b\x32\x12.angzarr.EventBookR\x06\x65vents\x12+\n\x11\x61lready_processed\x18\x02 \x01(\x08R\x10\x61lreadyProcessed\x12\x35\n\x0bprojections\x18\x03 \x03(\x0b\x32\x13.angzarr.ProjectionR\x0bprojections2\x93\x01\n\x15\x43ommandHandlerService\x12?\n\x06Handle\x12\x1a.angzarr.ContextualCommand\x1a\x19.angzarr.BusinessResponse\x12\x39\n\x06Replay\x12\x16.angzarr.ReplayRequest\x1a\x17.angzarr.ReplayResponse2\xac\x04\n CommandHandlerCoordinatorService\x12u\n\rHandleCommand\x12\x17.angzarr.CommandRequest\x1a\x18.angzarr.CommandResponse\"1\x82\xd3\xe4\x93\x02+\"&/v1/ch/{command.cover.domain}/commands:\x01*\x12t\n\x0bHandleEvent\x12\x15.angzarr.EventRequest\x1a\x1e.angzarr.FactInjectionResponse\".\x82\xd3\xe4\x93\x02(\"#/v1/ch/{events.cover.domain}/events:\x01*\x12\x99\x01\n\x15HandleSyncSpeculative\x12\'.angzarr.SpeculateCommandHandlerRequest\x1a\x18.angzarr.CommandResponse\"=\x82\xd3\xe4\x93\x02\x37\"2/v1/ch/{command.cover.domain}/commands/speculative:\x01*\x12\x7f\n\x12HandleCompensation\x12\x17.angzarr.CommandRequest\x1a\x19.angzarr.BusinessResponse\"5\x82\xd3\xe4\x93\x02/\"*/v1/ch/{command.cover.domain}/compensation:\x01*BM\n\x0b\x64\x65v.angzarrP\x01Z(github.com/angzarr/angzarr/proto/angzarr\xaa\x02\x07\x41ngzarr\xea\x02\x07\x41ngzarrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'angzarr.command_handler_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013dev.angzarrP\001Z(github.com/angzarr/angzarr/proto/angzarr\252\002\007Angzarr\352\002\007Angzarr'
  _globals['_COMMANDHANDLERCOORDINATORSERVICE'].methods_by_name['HandleCommand']._loaded_options = None
  _globals['_COMMANDHANDLERCOORDINATORSERVICE'].methods_by_name['HandleCommand']._serialized_options = b'\202\323\344\223\002+\"&/v1/ch/{command.cover.domain}/commands:\001*'
  _globals['_COMMANDHANDLERCOORDINATORSERVICE'].methods_by_name['HandleEvent']._loaded_options = None
  _globals['_COMMANDHANDLERCOORDINATORSERVICE'].methods_by_name['HandleEvent']._serialized_options = b'\202\323\344\223\002(\"#/v1/ch/{events.cover.domain}/events:\001*'
  _globals['_COMMANDHANDLERCOORDINATORSERVICE'].methods_by_name['HandleSyncSpeculative']._loaded_options = None
  _globals['_COMMANDHANDLERCOORDINATORSERVICE'].methods_by_name['HandleSyncSpeculative']._serialized_options = b'\202\323\344\223\0027\"2/v1/ch/{command.cover.domain}/commands/speculative:\001*'
  _globals['_COMMANDHANDLERCOORDINATORSERVICE'].methods_by_name['HandleCompensation']._loaded_options = None
  _globals['_COMMANDHANDLERCOORDINATORSERVICE'].methods_by_name['HandleCompensation']._serialized_options = b'\202\323\344\223\002/\"*/v1/ch/{command.cover.domain}/compensation:\001*'
  _globals['_REPLAYREQUEST']._serialized_start=120
  _globals['_REPLAYREQUEST']._serialized_end=235
  _globals['_REPLAYRESPONSE']._serialized_start=237
  _globals['_REPLAYRESPONSE']._serialized_end=297
  _globals['_COMMANDRESPONSE']._serialized_start=300
  _globals['_COMMANDRESPONSE']._serialized_end=478
  _globals['_CASCADEERROR']._serialized_start=481
  _globals['_CASCADEERROR']._serialized_end=647
  _globals['_REVOCATIONRESPONSE']._serialized_start=650
  _globals['_REVOCATIONRESPONSE']._serialized_end=856
  _globals['_BUSINESSRESPONSE']._serialized_start=859
  _globals['_BUSINESSRESPONSE']._serialized_end=1057
  _globals['_SPECULATECOMMANDHANDLERREQUEST']._serialized_start=1060
  _globals['_SPECULATECOMMANDHANDLERREQUEST']._serialized_end=1200
  _globals['_FACTINJECTIONRESPONSE']._serialized_start=1203
  _globals['_FACTINJECTIONRESPONSE']._serialized_end=1370
  _globals['_COMMANDHANDLERSERVICE']._serialized_start=1373
  _globals['_COMMANDHANDLERSERVICE']._serialized_end=1520
  _globals['_COMMANDHANDLERCOORDINATORSERVICE']._serialized_start=1523
  _globals['_COMMANDHANDLERCOORDINATORSERVICE']._serialized_end=2079
# @@protoc_insertion_point(module_scope)
