# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: examples/registration.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'examples/registration.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.examples import orchestration_pb2 as examples_dot_orchestration__pb2
from angzarr_client.proto.examples import poker_types_pb2 as examples_dot_poker__types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x65xamples/registration.proto\x12\x08\x65xamples\x1a\x1c\x65xamples/orchestration.proto\x1a\x1a\x65xamples/poker_types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"I\n\x1eInitiateTournamentRegistration\x12\'\n\x0ftournament_root\x18\x01 \x01(\x0cR\x0etournamentRoot\"?\n\x16\x43onfirmRegistrationFee\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\"W\n\x16ReleaseRegistrationFee\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"\xcc\x01\n\x15RegistrationRequested\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\'\n\x0ftournament_root\x18\x02 \x01(\x0cR\x0etournamentRoot\x12$\n\x03\x66\x65\x65\x18\x03 \x01(\x0b\x32\x12.examples.CurrencyR\x03\x66\x65\x65\x12=\n\x0crequested_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0brequestedAt\"\xcf\x01\n\x18RegistrationFeeConfirmed\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\'\n\x0ftournament_root\x18\x02 \x01(\x0cR\x0etournamentRoot\x12$\n\x03\x66\x65\x65\x18\x03 \x01(\x0b\x32\x12.examples.CurrencyR\x03\x66\x65\x65\x12=\n\x0c\x63onfirmed_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63onfirmedAt\"\x95\x01\n\x17RegistrationFeeReleased\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\x12;\n\x0breleased_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nreleasedAt\"\xa0\x02\n\x15RegistrationInitiated\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\'\n\x0ftournament_root\x18\x02 \x01(\x0cR\x0etournamentRoot\x12%\n\x0ereservation_id\x18\x03 \x01(\x0cR\rreservationId\x12$\n\x03\x66\x65\x65\x18\x04 \x01(\x0b\x32\x12.examples.CurrencyR\x03\x66\x65\x65\x12\x31\n\x05phase\x18\x05 \x01(\x0e\x32\x1b.examples.RegistrationPhaseR\x05phase\x12=\n\x0cinitiated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0binitiatedAt\"\x94\x02\n\x15RegistrationCompleted\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\'\n\x0ftournament_root\x18\x02 \x01(\x0cR\x0etournamentRoot\x12%\n\x0ereservation_id\x18\x03 \x01(\x0cR\rreservationId\x12$\n\x03\x66\x65\x65\x18\x04 \x01(\x0b\x32\x12.examples.CurrencyR\x03\x66\x65\x65\x12%\n\x0estarting_stack\x18\x05 \x01(\x03R\rstartingStack\x12=\n\x0c\x63ompleted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63ompletedAt\"\xbf\x01\n\x12RegistrationFailed\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\'\n\x0ftournament_root\x18\x02 \x01(\x0cR\x0etournamentRoot\x12%\n\x0ereservation_id\x18\x03 \x01(\x0cR\rreservationId\x12\x38\n\x07\x66\x61ilure\x18\x04 \x01(\x0b\x32\x1e.examples.OrchestrationFailureR\x07\x66\x61ilure\"\xf0\x01\n\x18RegistrationPhaseChanged\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12:\n\nfrom_phase\x18\x02 \x01(\x0e\x32\x1b.examples.RegistrationPhaseR\tfromPhase\x12\x36\n\x08to_phase\x18\x03 \x01(\x0e\x32\x1b.examples.RegistrationPhaseR\x07toPhase\x12\x39\n\nchanged_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tchangedAt\"\x90\x02\n\x1dRegistrationOrchestratorState\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x1f\n\x0bplayer_root\x18\x02 \x01(\x0cR\nplayerRoot\x12\'\n\x0ftournament_root\x18\x03 \x01(\x0cR\x0etournamentRoot\x12\x10\n\x03\x66\x65\x65\x18\x04 \x01(\x03R\x03\x66\x65\x65\x12\x31\n\x05phase\x18\x05 \x01(\x0e\x32\x1b.examples.RegistrationPhaseR\x05phase\x12\x39\n\nstarted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartedAtBj\n\x14\x64\x65v.angzarr.examplesP\x01Z)github.com/angzarr/angzarr/proto/examples\xaa\x02\x10\x41ngzarr.Examples\xea\x02\x11\x41ngzarr::Examplesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'examples.registration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024dev.angzarr.examplesP\001Z)github.com/angzarr/angzarr/proto/examples\252\002\020Angzarr.Examples\352\002\021Angzarr::Examples'
  _globals['_INITIATETOURNAMENTREGISTRATION']._serialized_start=132
  _globals['_INITIATETOURNAMENTREGISTRATION']._serialized_end=205
  _globals['_CONFIRMREGISTRATIONFEE']._serialized_start=207
  _globals['_CONFIRMREGISTRATIONFEE']._serialized_end=270
  _globals['_RELEASEREGISTRATIONFEE']._serialized_start=272
  _globals['_RELEASEREGISTRATIONFEE']._serialized_end=359
  _globals['_REGISTRATIONREQUESTED']._serialized_start=362
  _globals['_REGISTRATIONREQUESTED']._serialized_end=566
  _globals['_REGISTRATIONFEECONFIRMED']._serialized_start=569
  _globals['_REGISTRATIONFEECONFIRMED']._serialized_end=776
  _globals['_REGISTRATIONFEERELEASED']._serialized_start=779
  _globals['_REGISTRATIONFEERELEASED']._serialized_end=928
  _globals['_REGISTRATIONINITIATED']._serialized_start=931
  _globals['_REGISTRATIONINITIATED']._serialized_end=1219
  _globals['_REGISTRATIONCOMPLETED']._serialized_start=1222
  _globals['_REGISTRATIONCOMPLETED']._serialized_end=1498
  _globals['_REGISTRATIONFAILED']._serialized_start=1501
  _globals['_REGISTRATIONFAILED']._serialized_end=1692
  _globals['_REGISTRATIONPHASECHANGED']._serialized_start=1695
  _globals['_REGISTRATIONPHASECHANGED']._serialized_end=1935
  _globals['_REGISTRATIONORCHESTRATORSTATE']._serialized_start=1938
  _globals['_REGISTRATIONORCHESTRATORSTATE']._serialized_end=2210
# @@protoc_insertion_point(module_scope)
