# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: examples/buy_in.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'examples/buy_in.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.examples import orchestration_pb2 as examples_dot_orchestration__pb2
from angzarr_client.proto.examples import poker_types_pb2 as examples_dot_poker__types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x65xamples/buy_in.proto\x12\x08\x65xamples\x1a\x1c\x65xamples/orchestration.proto\x1a\x1a\x65xamples/poker_types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"n\n\rInitiateBuyIn\x12\x1d\n\ntable_root\x18\x01 \x01(\x0cR\ttableRoot\x12\x12\n\x04seat\x18\x02 \x01(\x05R\x04seat\x12*\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x12.examples.CurrencyR\x06\x61mount\"5\n\x0c\x43onfirmBuyIn\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\"M\n\x0cReleaseBuyIn\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"\x80\x01\n\nSeatPlayer\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\x12\x12\n\x04seat\x18\x03 \x01(\x05R\x04seat\x12\x16\n\x06\x61mount\x18\x04 \x01(\x03R\x06\x61mount\"\xd5\x01\n\x0e\x42uyInRequested\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x1d\n\ntable_root\x18\x02 \x01(\x0cR\ttableRoot\x12\x12\n\x04seat\x18\x03 \x01(\x05R\x04seat\x12*\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x12.examples.CurrencyR\x06\x61mount\x12=\n\x0crequested_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0brequestedAt\"\xd5\x01\n\x0e\x42uyInConfirmed\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x1d\n\ntable_root\x18\x02 \x01(\x0cR\ttableRoot\x12\x12\n\x04seat\x18\x03 \x01(\x05R\x04seat\x12*\n\x06\x61mount\x18\x04 \x01(\x0b\x32\x12.examples.CurrencyR\x06\x61mount\x12=\n\x0c\x63onfirmed_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63onfirmedAt\"\x96\x01\n\x18\x42uyInReservationReleased\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\x12;\n\x0breleased_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nreleasedAt\"\xca\x01\n\x0cPlayerSeated\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\x12#\n\rseat_position\x18\x03 \x01(\x05R\x0cseatPosition\x12\x14\n\x05stack\x18\x04 \x01(\x03R\x05stack\x12\x37\n\tseated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08seatedAt\"\xd5\x01\n\x0fSeatingRejected\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\x12%\n\x0erequested_seat\x18\x03 \x01(\x05R\rrequestedSeat\x12\x16\n\x06reason\x18\x04 \x01(\tR\x06reason\x12;\n\x0brejected_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrejectedAt\"\xa2\x02\n\x0e\x42uyInInitiated\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\x1d\n\ntable_root\x18\x02 \x01(\x0cR\ttableRoot\x12%\n\x0ereservation_id\x18\x03 \x01(\x0cR\rreservationId\x12\x12\n\x04seat\x18\x04 \x01(\x05R\x04seat\x12*\n\x06\x61mount\x18\x05 \x01(\x0b\x32\x12.examples.CurrencyR\x06\x61mount\x12*\n\x05phase\x18\x06 \x01(\x0e\x32\x14.examples.BuyInPhaseR\x05phase\x12=\n\x0cinitiated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0binitiatedAt\"\xf6\x01\n\x0e\x42uyInCompleted\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\x1d\n\ntable_root\x18\x02 \x01(\x0cR\ttableRoot\x12%\n\x0ereservation_id\x18\x03 \x01(\x0cR\rreservationId\x12\x12\n\x04seat\x18\x04 \x01(\x05R\x04seat\x12*\n\x06\x61mount\x18\x05 \x01(\x0b\x32\x12.examples.CurrencyR\x06\x61mount\x12=\n\x0c\x63ompleted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63ompletedAt\"\xae\x01\n\x0b\x42uyInFailed\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\x1d\n\ntable_root\x18\x02 \x01(\x0cR\ttableRoot\x12%\n\x0ereservation_id\x18\x03 \x01(\x0cR\rreservationId\x12\x38\n\x07\x66\x61ilure\x18\x04 \x01(\x0b\x32\x1e.examples.OrchestrationFailureR\x07\x66\x61ilure\"\xdb\x01\n\x11\x42uyInPhaseChanged\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x33\n\nfrom_phase\x18\x02 \x01(\x0e\x32\x14.examples.BuyInPhaseR\tfromPhase\x12/\n\x08to_phase\x18\x03 \x01(\x0e\x32\x14.examples.BuyInPhaseR\x07toPhase\x12\x39\n\nchanged_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tchangedAt\"\x92\x02\n\x16\x42uyInOrchestratorState\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x1f\n\x0bplayer_root\x18\x02 \x01(\x0cR\nplayerRoot\x12\x1d\n\ntable_root\x18\x03 \x01(\x0cR\ttableRoot\x12\x12\n\x04seat\x18\x04 \x01(\x05R\x04seat\x12\x16\n\x06\x61mount\x18\x05 \x01(\x03R\x06\x61mount\x12*\n\x05phase\x18\x06 \x01(\x0e\x32\x14.examples.BuyInPhaseR\x05phase\x12\x39\n\nstarted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartedAtBj\n\x14\x64\x65v.angzarr.examplesP\x01Z)github.com/angzarr/angzarr/proto/examples\xaa\x02\x10\x41ngzarr.Examples\xea\x02\x11\x41ngzarr::Examplesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'examples.buy_in_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024dev.angzarr.examplesP\001Z)github.com/angzarr/angzarr/proto/examples\252\002\020Angzarr.Examples\352\002\021Angzarr::Examples'
  _globals['_INITIATEBUYIN']._serialized_start=126
  _globals['_INITIATEBUYIN']._serialized_end=236
  _globals['_CONFIRMBUYIN']._serialized_start=238
  _globals['_CONFIRMBUYIN']._serialized_end=291
  _globals['_RELEASEBUYIN']._serialized_start=293
  _globals['_RELEASEBUYIN']._serialized_end=370
  _globals['_SEATPLAYER']._serialized_start=373
  _globals['_SEATPLAYER']._serialized_end=501
  _globals['_BUYINREQUESTED']._serialized_start=504
  _globals['_BUYINREQUESTED']._serialized_end=717
  _globals['_BUYINCONFIRMED']._serialized_start=720
  _globals['_BUYINCONFIRMED']._serialized_end=933
  _globals['_BUYINRESERVATIONRELEASED']._serialized_start=936
  _globals['_BUYINRESERVATIONRELEASED']._serialized_end=1086
  _globals['_PLAYERSEATED']._serialized_start=1089
  _globals['_PLAYERSEATED']._serialized_end=1291
  _globals['_SEATINGREJECTED']._serialized_start=1294
  _globals['_SEATINGREJECTED']._serialized_end=1507
  _globals['_BUYININITIATED']._serialized_start=1510
  _globals['_BUYININITIATED']._serialized_end=1800
  _globals['_BUYINCOMPLETED']._serialized_start=1803
  _globals['_BUYINCOMPLETED']._serialized_end=2049
  _globals['_BUYINFAILED']._serialized_start=2052
  _globals['_BUYINFAILED']._serialized_end=2226
  _globals['_BUYINPHASECHANGED']._serialized_start=2229
  _globals['_BUYINPHASECHANGED']._serialized_end=2448
  _globals['_BUYINORCHESTRATORSTATE']._serialized_start=2451
  _globals['_BUYINORCHESTRATORSTATE']._serialized_end=2725
# @@protoc_insertion_point(module_scope)
