# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: io/cloudevents/v1/cloudevents.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'io/cloudevents/v1/cloudevents.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#io/cloudevents/v1/cloudevents.proto\x12\x11io.cloudevents.v1\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa7\x03\n\nCloudEvent\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06source\x18\x02 \x01(\tR\x06source\x12!\n\x0cspec_version\x18\x03 \x01(\tR\x0bspecVersion\x12\x12\n\x04type\x18\x04 \x01(\tR\x04type\x12M\n\nattributes\x18\x05 \x03(\x0b\x32-.io.cloudevents.v1.CloudEvent.AttributesEntryR\nattributes\x12!\n\x0b\x62inary_data\x18\x06 \x01(\x0cH\x00R\nbinaryData\x12\x1d\n\ttext_data\x18\x07 \x01(\tH\x00R\x08textData\x12\x35\n\nproto_data\x18\x08 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00R\tprotoData\x1aj\n\x0f\x41ttributesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32+.io.cloudevents.v1.CloudEventAttributeValueR\x05value:\x02\x38\x01\x42\x06\n\x04\x64\x61ta\"\x9a\x02\n\x18\x43loudEventAttributeValue\x12\x1f\n\nce_boolean\x18\x01 \x01(\x08H\x00R\tceBoolean\x12\x1f\n\nce_integer\x18\x02 \x01(\x05H\x00R\tceInteger\x12\x1d\n\tce_string\x18\x03 \x01(\tH\x00R\x08\x63\x65String\x12\x1b\n\x08\x63\x65_bytes\x18\x04 \x01(\x0cH\x00R\x07\x63\x65\x42ytes\x12\x17\n\x06\x63\x65_uri\x18\x05 \x01(\tH\x00R\x05\x63\x65Uri\x12\x1e\n\nce_uri_ref\x18\x06 \x01(\tH\x00R\x08\x63\x65UriRef\x12?\n\x0c\x63\x65_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x0b\x63\x65TimestampB\x06\n\x04\x61ttr\"H\n\x0f\x43loudEventBatch\x12\x35\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1d.io.cloudevents.v1.CloudEventR\x06\x65ventsB\xaf\x01\n\x17io.cloudevents.v1.protoP\x01Z>github.com/cloudevents/sdk-go/binding/format/protobuf/v2/pb;pb\xaa\x02\x1a\x43loudNative.CloudEvents.V1\xca\x02\x17Io\\CloudEvents\\V1\\Proto\xea\x02\x1aIo::CloudEvents::V1::Protob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'io.cloudevents.v1.cloudevents_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027io.cloudevents.v1.protoP\001Z>github.com/cloudevents/sdk-go/binding/format/protobuf/v2/pb;pb\252\002\032CloudNative.CloudEvents.V1\312\002\027Io\\CloudEvents\\V1\\Proto\352\002\032Io::CloudEvents::V1::Proto'
  _globals['_CLOUDEVENT_ATTRIBUTESENTRY']._loaded_options = None
  _globals['_CLOUDEVENT_ATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_CLOUDEVENT']._serialized_start=119
  _globals['_CLOUDEVENT']._serialized_end=542
  _globals['_CLOUDEVENT_ATTRIBUTESENTRY']._serialized_start=428
  _globals['_CLOUDEVENT_ATTRIBUTESENTRY']._serialized_end=534
  _globals['_CLOUDEVENTATTRIBUTEVALUE']._serialized_start=545
  _globals['_CLOUDEVENTATTRIBUTEVALUE']._serialized_end=827
  _globals['_CLOUDEVENTBATCH']._serialized_start=829
  _globals['_CLOUDEVENTBATCH']._serialized_end=901
# @@protoc_insertion_point(module_scope)
