# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: examples/tournament.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'examples/tournament.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.examples import poker_types_pb2 as examples_dot_poker__types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x65xamples/tournament.proto\x12\x08\x65xamples\x1a\x1a\x65xamples/poker_types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdd\x01\n\x0bRebuyConfig\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x12\x1d\n\nmax_rebuys\x18\x02 \x01(\x05R\tmaxRebuys\x12,\n\x12rebuy_level_cutoff\x18\x03 \x01(\x05R\x10rebuyLevelCutoff\x12\'\n\x0fstack_threshold\x18\x04 \x01(\x03R\x0estackThreshold\x12\x1d\n\nrebuy_cost\x18\x05 \x01(\x03R\trebuyCost\x12\x1f\n\x0brebuy_chips\x18\x06 \x01(\x03R\nrebuyChips\"\x88\x01\n\x0b\x41\x64\x64onConfig\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\x12\x1f\n\x0b\x61\x64\x64on_level\x18\x02 \x01(\x05R\naddonLevel\x12\x1d\n\naddon_cost\x18\x03 \x01(\x03R\taddonCost\x12\x1f\n\x0b\x61\x64\x64on_chips\x18\x04 \x01(\x03R\naddonChips\"\xce\x02\n\x12PlayerRegistration\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\x19\n\x08\x66\x65\x65_paid\x18\x02 \x01(\x03R\x07\x66\x65\x65Paid\x12%\n\x0estarting_stack\x18\x03 \x01(\x03R\rstartingStack\x12\x1f\n\x0brebuys_used\x18\x04 \x01(\x05R\nrebuysUsed\x12\x1f\n\x0b\x61\x64\x64on_taken\x18\x05 \x01(\x08R\naddonTaken\x12)\n\x10table_assignment\x18\x06 \x01(\x05R\x0ftableAssignment\x12\'\n\x0fseat_assignment\x18\x07 \x01(\x05R\x0eseatAssignment\x12?\n\rregistered_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cregisteredAt\"\xd8\x03\n\x10\x43reateTournament\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x38\n\x0cgame_variant\x18\x02 \x01(\x0e\x32\x15.examples.GameVariantR\x0bgameVariant\x12\x15\n\x06\x62uy_in\x18\x03 \x01(\x03R\x05\x62uyIn\x12%\n\x0estarting_stack\x18\x04 \x01(\x03R\rstartingStack\x12\x1f\n\x0bmax_players\x18\x05 \x01(\x05R\nmaxPlayers\x12\x1f\n\x0bmin_players\x18\x06 \x01(\x05R\nminPlayers\x12\x43\n\x0fscheduled_start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0escheduledStart\x12\x38\n\x0crebuy_config\x18\x08 \x01(\x0b\x32\x15.examples.RebuyConfigR\x0brebuyConfig\x12\x38\n\x0c\x61\x64\x64on_config\x18\t \x01(\x0b\x32\x15.examples.AddonConfigR\x0b\x61\x64\x64onConfig\x12=\n\x0f\x62lind_structure\x18\n \x03(\x0b\x32\x14.examples.BlindLevelR\x0e\x62lindStructure\"\x12\n\x10OpenRegistration\"\x13\n\x11\x43loseRegistration\"V\n\x0c\x45nrollPlayer\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\"3\n\x10UnregisterPlayer\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\"\x11\n\x0fStartTournament\"V\n\x0cProcessRebuy\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\"V\n\x0cProcessAddon\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\"\x13\n\x11\x41\x64vanceBlindLevel\"O\n\x0f\x45liminatePlayer\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\x1b\n\thand_root\x18\x02 \x01(\x0cR\x08handRoot\")\n\x0fPauseTournament\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\"\x12\n\x10ResumeTournament\"\x94\x04\n\x11TournamentCreated\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x38\n\x0cgame_variant\x18\x02 \x01(\x0e\x32\x15.examples.GameVariantR\x0bgameVariant\x12\x15\n\x06\x62uy_in\x18\x03 \x01(\x03R\x05\x62uyIn\x12%\n\x0estarting_stack\x18\x04 \x01(\x03R\rstartingStack\x12\x1f\n\x0bmax_players\x18\x05 \x01(\x05R\nmaxPlayers\x12\x1f\n\x0bmin_players\x18\x06 \x01(\x05R\nminPlayers\x12\x43\n\x0fscheduled_start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0escheduledStart\x12\x38\n\x0crebuy_config\x18\x08 \x01(\x0b\x32\x15.examples.RebuyConfigR\x0brebuyConfig\x12\x38\n\x0c\x61\x64\x64on_config\x18\t \x01(\x0b\x32\x15.examples.AddonConfigR\x0b\x61\x64\x64onConfig\x12=\n\x0f\x62lind_structure\x18\n \x03(\x0b\x32\x14.examples.BlindLevelR\x0e\x62lindStructure\x12\x39\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"M\n\x12RegistrationOpened\x12\x37\n\topened_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08openedAt\"~\n\x12RegistrationClosed\x12/\n\x13total_registrations\x18\x01 \x01(\x05R\x12totalRegistrations\x12\x37\n\tclosed_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x63losedAt\"\x92\x02\n\x18TournamentPlayerEnrolled\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\x12\x19\n\x08\x66\x65\x65_paid\x18\x03 \x01(\x03R\x07\x66\x65\x65Paid\x12%\n\x0estarting_stack\x18\x04 \x01(\x03R\rstartingStack\x12/\n\x13registration_number\x18\x05 \x01(\x05R\x12registrationNumber\x12;\n\x0b\x65nrolled_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nenrolledAt\"\xbb\x01\n\x1cTournamentEnrollmentRejected\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\x12\x16\n\x06reason\x18\x03 \x01(\tR\x06reason\x12;\n\x0brejected_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrejectedAt\"\x9f\x01\n\x12PlayerUnregistered\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12#\n\rrefund_amount\x18\x02 \x01(\x03R\x0crefundAmount\x12\x43\n\x0funregistered_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0eunregisteredAt\"\xc4\x01\n\x11TournamentStarted\x12#\n\rtotal_players\x18\x01 \x01(\x05R\x0ctotalPlayers\x12%\n\x0etables_created\x18\x02 \x01(\x05R\rtablesCreated\x12(\n\x10total_prize_pool\x18\x03 \x01(\x03R\x0etotalPrizePool\x12\x39\n\nstarted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartedAt\"\xf8\x01\n\x0eRebuyProcessed\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\x12\x1d\n\nrebuy_cost\x18\x03 \x01(\x03R\trebuyCost\x12\x1f\n\x0b\x63hips_added\x18\x04 \x01(\x03R\nchipsAdded\x12\x1f\n\x0brebuy_count\x18\x05 \x01(\x05R\nrebuyCount\x12=\n\x0cprocessed_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bprocessedAt\"\xa6\x01\n\x0bRebuyDenied\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\x12\x16\n\x06reason\x18\x03 \x01(\tR\x06reason\x12\x37\n\tdenied_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x64\x65niedAt\"\xd7\x01\n\x0e\x41\x64\x64onProcessed\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\x12\x1d\n\naddon_cost\x18\x03 \x01(\x03R\taddonCost\x12\x1f\n\x0b\x63hips_added\x18\x04 \x01(\x03R\nchipsAdded\x12=\n\x0cprocessed_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bprocessedAt\"\xb9\x01\n\x12\x42lindLevelAdvanced\x12\x14\n\x05level\x18\x01 \x01(\x05R\x05level\x12\x1f\n\x0bsmall_blind\x18\x02 \x01(\x03R\nsmallBlind\x12\x1b\n\tbig_blind\x18\x03 \x01(\x03R\x08\x62igBlind\x12\x12\n\x04\x61nte\x18\x04 \x01(\x03R\x04\x61nte\x12;\n\x0b\x61\x64vanced_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nadvancedAt\"\xd2\x01\n\x10PlayerEliminated\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\'\n\x0f\x66inish_position\x18\x02 \x01(\x05R\x0e\x66inishPosition\x12\x1b\n\thand_root\x18\x03 \x01(\x0cR\x08handRoot\x12\x16\n\x06payout\x18\x04 \x01(\x03R\x06payout\x12?\n\reliminated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0c\x65liminatedAt\"c\n\x10TournamentPaused\x12\x16\n\x06reason\x18\x01 \x01(\tR\x06reason\x12\x37\n\tpaused_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08pausedAt\"N\n\x11TournamentResumed\x12\x39\n\nresumed_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tresumedAt\"\xd5\x01\n\x13TournamentCompleted\x12\x1f\n\x0bwinner_root\x18\x01 \x01(\x0cR\nwinnerRoot\x12(\n\x10total_prize_pool\x18\x02 \x01(\x03R\x0etotalPrizePool\x12\x34\n\x07results\x18\x03 \x03(\x0b\x32\x1a.examples.TournamentResultR\x07results\x12=\n\x0c\x63ompleted_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63ompletedAt\"g\n\x10TournamentResult\x12\x1a\n\x08position\x18\x01 \x01(\x05R\x08position\x12\x1f\n\x0bplayer_root\x18\x02 \x01(\x0cR\nplayerRoot\x12\x16\n\x06payout\x18\x03 \x01(\x03R\x06payout\"\x9f\x01\n\nBlindLevel\x12\x14\n\x05level\x18\x01 \x01(\x05R\x05level\x12\x1f\n\x0bsmall_blind\x18\x02 \x01(\x03R\nsmallBlind\x12\x1b\n\tbig_blind\x18\x03 \x01(\x03R\x08\x62igBlind\x12\x12\n\x04\x61nte\x18\x04 \x01(\x03R\x04\x61nte\x12)\n\x10\x64uration_minutes\x18\x05 \x01(\x05R\x0f\x64urationMinutes\"\xf1\x06\n\x0fTournamentState\x12#\n\rtournament_id\x18\x01 \x01(\tR\x0ctournamentId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x38\n\x0cgame_variant\x18\x03 \x01(\x0e\x32\x15.examples.GameVariantR\x0bgameVariant\x12\x32\n\x06status\x18\x04 \x01(\x0e\x32\x1a.examples.TournamentStatusR\x06status\x12\x15\n\x06\x62uy_in\x18\x05 \x01(\x03R\x05\x62uyIn\x12%\n\x0estarting_stack\x18\x06 \x01(\x03R\rstartingStack\x12\x1f\n\x0bmax_players\x18\x07 \x01(\x05R\nmaxPlayers\x12\x1f\n\x0bmin_players\x18\x08 \x01(\x05R\nminPlayers\x12\x43\n\x0fscheduled_start\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0escheduledStart\x12\x38\n\x0crebuy_config\x18\n \x01(\x0b\x32\x15.examples.RebuyConfigR\x0brebuyConfig\x12\x38\n\x0c\x61\x64\x64on_config\x18\x0b \x01(\x0b\x32\x15.examples.AddonConfigR\x0b\x61\x64\x64onConfig\x12=\n\x0f\x62lind_structure\x18\x0c \x03(\x0b\x32\x14.examples.BlindLevelR\x0e\x62lindStructure\x12#\n\rcurrent_level\x18\r \x01(\x05R\x0c\x63urrentLevel\x12_\n\x12registered_players\x18\x0e \x03(\x0b\x32\x30.examples.TournamentState.RegisteredPlayersEntryR\x11registeredPlayers\x12+\n\x11players_remaining\x18\x0f \x01(\x05R\x10playersRemaining\x12(\n\x10total_prize_pool\x18\x10 \x01(\x03R\x0etotalPrizePool\x1a\x62\n\x16RegisteredPlayersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32\x1c.examples.PlayerRegistrationR\x05value:\x02\x38\x01*\xd2\x01\n\x10TournamentStatus\x12!\n\x1dTOURNAMENT_STATUS_UNSPECIFIED\x10\x00\x12\x16\n\x12TOURNAMENT_CREATED\x10\x01\x12 \n\x1cTOURNAMENT_REGISTRATION_OPEN\x10\x02\x12\x16\n\x12TOURNAMENT_RUNNING\x10\x03\x12\x15\n\x11TOURNAMENT_PAUSED\x10\x04\x12\x18\n\x14TOURNAMENT_COMPLETED\x10\x05\x12\x18\n\x14TOURNAMENT_CANCELLED\x10\x06\x42j\n\x14\x64\x65v.angzarr.examplesP\x01Z)github.com/angzarr/angzarr/proto/examples\xaa\x02\x10\x41ngzarr.Examples\xea\x02\x11\x41ngzarr::Examplesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'examples.tournament_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024dev.angzarr.examplesP\001Z)github.com/angzarr/angzarr/proto/examples\252\002\020Angzarr.Examples\352\002\021Angzarr::Examples'
  _globals['_TOURNAMENTSTATE_REGISTEREDPLAYERSENTRY']._loaded_options = None
  _globals['_TOURNAMENTSTATE_REGISTEREDPLAYERSENTRY']._serialized_options = b'8\001'
  _globals['_TOURNAMENTSTATUS']._serialized_start=5975
  _globals['_TOURNAMENTSTATUS']._serialized_end=6185
  _globals['_REBUYCONFIG']._serialized_start=101
  _globals['_REBUYCONFIG']._serialized_end=322
  _globals['_ADDONCONFIG']._serialized_start=325
  _globals['_ADDONCONFIG']._serialized_end=461
  _globals['_PLAYERREGISTRATION']._serialized_start=464
  _globals['_PLAYERREGISTRATION']._serialized_end=798
  _globals['_CREATETOURNAMENT']._serialized_start=801
  _globals['_CREATETOURNAMENT']._serialized_end=1273
  _globals['_OPENREGISTRATION']._serialized_start=1275
  _globals['_OPENREGISTRATION']._serialized_end=1293
  _globals['_CLOSEREGISTRATION']._serialized_start=1295
  _globals['_CLOSEREGISTRATION']._serialized_end=1314
  _globals['_ENROLLPLAYER']._serialized_start=1316
  _globals['_ENROLLPLAYER']._serialized_end=1402
  _globals['_UNREGISTERPLAYER']._serialized_start=1404
  _globals['_UNREGISTERPLAYER']._serialized_end=1455
  _globals['_STARTTOURNAMENT']._serialized_start=1457
  _globals['_STARTTOURNAMENT']._serialized_end=1474
  _globals['_PROCESSREBUY']._serialized_start=1476
  _globals['_PROCESSREBUY']._serialized_end=1562
  _globals['_PROCESSADDON']._serialized_start=1564
  _globals['_PROCESSADDON']._serialized_end=1650
  _globals['_ADVANCEBLINDLEVEL']._serialized_start=1652
  _globals['_ADVANCEBLINDLEVEL']._serialized_end=1671
  _globals['_ELIMINATEPLAYER']._serialized_start=1673
  _globals['_ELIMINATEPLAYER']._serialized_end=1752
  _globals['_PAUSETOURNAMENT']._serialized_start=1754
  _globals['_PAUSETOURNAMENT']._serialized_end=1795
  _globals['_RESUMETOURNAMENT']._serialized_start=1797
  _globals['_RESUMETOURNAMENT']._serialized_end=1815
  _globals['_TOURNAMENTCREATED']._serialized_start=1818
  _globals['_TOURNAMENTCREATED']._serialized_end=2350
  _globals['_REGISTRATIONOPENED']._serialized_start=2352
  _globals['_REGISTRATIONOPENED']._serialized_end=2429
  _globals['_REGISTRATIONCLOSED']._serialized_start=2431
  _globals['_REGISTRATIONCLOSED']._serialized_end=2557
  _globals['_TOURNAMENTPLAYERENROLLED']._serialized_start=2560
  _globals['_TOURNAMENTPLAYERENROLLED']._serialized_end=2834
  _globals['_TOURNAMENTENROLLMENTREJECTED']._serialized_start=2837
  _globals['_TOURNAMENTENROLLMENTREJECTED']._serialized_end=3024
  _globals['_PLAYERUNREGISTERED']._serialized_start=3027
  _globals['_PLAYERUNREGISTERED']._serialized_end=3186
  _globals['_TOURNAMENTSTARTED']._serialized_start=3189
  _globals['_TOURNAMENTSTARTED']._serialized_end=3385
  _globals['_REBUYPROCESSED']._serialized_start=3388
  _globals['_REBUYPROCESSED']._serialized_end=3636
  _globals['_REBUYDENIED']._serialized_start=3639
  _globals['_REBUYDENIED']._serialized_end=3805
  _globals['_ADDONPROCESSED']._serialized_start=3808
  _globals['_ADDONPROCESSED']._serialized_end=4023
  _globals['_BLINDLEVELADVANCED']._serialized_start=4026
  _globals['_BLINDLEVELADVANCED']._serialized_end=4211
  _globals['_PLAYERELIMINATED']._serialized_start=4214
  _globals['_PLAYERELIMINATED']._serialized_end=4424
  _globals['_TOURNAMENTPAUSED']._serialized_start=4426
  _globals['_TOURNAMENTPAUSED']._serialized_end=4525
  _globals['_TOURNAMENTRESUMED']._serialized_start=4527
  _globals['_TOURNAMENTRESUMED']._serialized_end=4605
  _globals['_TOURNAMENTCOMPLETED']._serialized_start=4608
  _globals['_TOURNAMENTCOMPLETED']._serialized_end=4821
  _globals['_TOURNAMENTRESULT']._serialized_start=4823
  _globals['_TOURNAMENTRESULT']._serialized_end=4926
  _globals['_BLINDLEVEL']._serialized_start=4929
  _globals['_BLINDLEVEL']._serialized_end=5088
  _globals['_TOURNAMENTSTATE']._serialized_start=5091
  _globals['_TOURNAMENTSTATE']._serialized_end=5972
  _globals['_TOURNAMENTSTATE_REGISTEREDPLAYERSENTRY']._serialized_start=5874
  _globals['_TOURNAMENTSTATE_REGISTEREDPLAYERSENTRY']._serialized_end=5972
# @@protoc_insertion_point(module_scope)
