# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: angzarr/meta.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'angzarr/meta.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.angzarr import types_pb2 as angzarr_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61ngzarr/meta.proto\x12\x07\x61ngzarr\x1a\x13\x61ngzarr/types.proto\"G\n\x13\x44\x65leteEditionEvents\x12\x18\n\x07\x65\x64ition\x18\x01 \x01(\tR\x07\x65\x64ition\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\"\x8c\x01\n\x14\x45\x64itionEventsDeleted\x12\x18\n\x07\x65\x64ition\x18\x01 \x01(\tR\x07\x65\x64ition\x12\x16\n\x06\x64omain\x18\x02 \x01(\tR\x06\x64omain\x12#\n\rdeleted_count\x18\x03 \x01(\rR\x0c\x64\x65letedCount\x12\x1d\n\ndeleted_at\x18\x04 \x01(\tR\tdeletedAtBM\n\x0b\x64\x65v.angzarrP\x01Z(github.com/angzarr/angzarr/proto/angzarr\xaa\x02\x07\x41ngzarr\xea\x02\x07\x41ngzarrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'angzarr.meta_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013dev.angzarrP\001Z(github.com/angzarr/angzarr/proto/angzarr\252\002\007Angzarr\352\002\007Angzarr'
  _globals['_DELETEEDITIONEVENTS']._serialized_start=52
  _globals['_DELETEEDITIONEVENTS']._serialized_end=123
  _globals['_EDITIONEVENTSDELETED']._serialized_start=126
  _globals['_EDITIONEVENTSDELETED']._serialized_end=266
# @@protoc_insertion_point(module_scope)
