# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: angzarr/query.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'angzarr/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.angzarr import types_pb2 as angzarr_dot_types__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from angzarr_client.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61ngzarr/query.proto\x12\x07\x61ngzarr\x1a\x13\x61ngzarr/types.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto2\xef\x02\n\x11\x45ventQueryService\x12[\n\x0cGetEventBook\x12\x0e.angzarr.Query\x1a\x12.angzarr.EventBook\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/query/{cover.domain}/events\x12\x61\n\tGetEvents\x12\x0e.angzarr.Query\x1a\x12.angzarr.EventBook\".\x82\xd3\xe4\x93\x02(\x12&/v1/query/{cover.domain}/events/stream0\x01\x12\x35\n\x0bSynchronize\x12\x0e.angzarr.Query\x1a\x12.angzarr.EventBook(\x01\x30\x01\x12\x63\n\x11GetAggregateRoots\x12\x16.google.protobuf.Empty\x1a\x16.angzarr.AggregateRoot\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/query/aggregates0\x01\x42`\n\x0b\x64\x65v.angzarrB\x11QueryServiceProtoP\x01Z(github.com/angzarr/angzarr/proto/angzarr\xaa\x02\x07\x41ngzarr\xea\x02\x07\x41ngzarrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'angzarr.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013dev.angzarrB\021QueryServiceProtoP\001Z(github.com/angzarr/angzarr/proto/angzarr\252\002\007Angzarr\352\002\007Angzarr'
  _globals['_EVENTQUERYSERVICE'].methods_by_name['GetEventBook']._loaded_options = None
  _globals['_EVENTQUERYSERVICE'].methods_by_name['GetEventBook']._serialized_options = b'\202\323\344\223\002!\022\037/v1/query/{cover.domain}/events'
  _globals['_EVENTQUERYSERVICE'].methods_by_name['GetEvents']._loaded_options = None
  _globals['_EVENTQUERYSERVICE'].methods_by_name['GetEvents']._serialized_options = b'\202\323\344\223\002(\022&/v1/query/{cover.domain}/events/stream'
  _globals['_EVENTQUERYSERVICE'].methods_by_name['GetAggregateRoots']._loaded_options = None
  _globals['_EVENTQUERYSERVICE'].methods_by_name['GetAggregateRoots']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/query/aggregates'
  _globals['_EVENTQUERYSERVICE']._serialized_start=113
  _globals['_EVENTQUERYSERVICE']._serialized_end=480
# @@protoc_insertion_point(module_scope)
