# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: angzarr/stream.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'angzarr/stream.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.angzarr import types_pb2 as angzarr_dot_types__pb2
from angzarr_client.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61ngzarr/stream.proto\x12\x07\x61ngzarr\x1a\x13\x61ngzarr/types.proto\x1a\x1cgoogle/api/annotations.proto2x\n\x12\x45ventStreamService\x12\x62\n\tSubscribe\x12\x1a.angzarr.EventStreamFilter\x1a\x12.angzarr.EventBook\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/stream/{correlation_id}0\x01\x42M\n\x0b\x64\x65v.angzarrP\x01Z(github.com/angzarr/angzarr/proto/angzarr\xaa\x02\x07\x41ngzarr\xea\x02\x07\x41ngzarrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'angzarr.stream_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013dev.angzarrP\001Z(github.com/angzarr/angzarr/proto/angzarr\252\002\007Angzarr\352\002\007Angzarr'
  _globals['_EVENTSTREAMSERVICE'].methods_by_name['Subscribe']._loaded_options = None
  _globals['_EVENTSTREAMSERVICE'].methods_by_name['Subscribe']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/stream/{correlation_id}'
  _globals['_EVENTSTREAMSERVICE']._serialized_start=84
  _globals['_EVENTSTREAMSERVICE']._serialized_end=204
# @@protoc_insertion_point(module_scope)
