# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: examples/orchestration.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'examples/orchestration.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x65xamples/orchestration.proto\x12\x08\x65xamples\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x01\n\x14OrchestrationFailure\x12\x12\n\x04\x63ode\x18\x01 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12&\n\x0f\x66\x61iled_at_phase\x18\x03 \x01(\tR\rfailedAtPhase\x12\x37\n\tfailed_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x66\x61iledAt*\xaa\x01\n\nBuyInPhase\x12\x1c\n\x18\x42UY_IN_PHASE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42UY_IN_REQUESTED\x10\x01\x12\x14\n\x10\x42UY_IN_RESERVING\x10\x02\x12\x12\n\x0e\x42UY_IN_SEATING\x10\x03\x12\x15\n\x11\x42UY_IN_CONFIRMING\x10\x04\x12\x14\n\x10\x42UY_IN_COMPLETED\x10\x05\x12\x11\n\rBUY_IN_FAILED\x10\x06*\xdd\x01\n\x11RegistrationPhase\x12\"\n\x1eREGISTRATION_PHASE_UNSPECIFIED\x10\x00\x12\x1a\n\x16REGISTRATION_REQUESTED\x10\x01\x12\x1a\n\x16REGISTRATION_RESERVING\x10\x02\x12\x1a\n\x16REGISTRATION_ENROLLING\x10\x03\x12\x1b\n\x17REGISTRATION_CONFIRMING\x10\x04\x12\x1a\n\x16REGISTRATION_COMPLETED\x10\x05\x12\x17\n\x13REGISTRATION_FAILED\x10\x06*\xbd\x01\n\nRebuyPhase\x12\x1b\n\x17REBUY_PHASE_UNSPECIFIED\x10\x00\x12\x13\n\x0fREBUY_REQUESTED\x10\x01\x12\x13\n\x0fREBUY_RESERVING\x10\x02\x12\x13\n\x0fREBUY_APPROVING\x10\x03\x12\x16\n\x12REBUY_ADDING_CHIPS\x10\x04\x12\x14\n\x10REBUY_CONFIRMING\x10\x05\x12\x13\n\x0fREBUY_COMPLETED\x10\x06\x12\x10\n\x0cREBUY_FAILED\x10\x07\x42j\n\x14\x64\x65v.angzarr.examplesP\x01Z)github.com/angzarr/angzarr/proto/examples\xaa\x02\x10\x41ngzarr.Examples\xea\x02\x11\x41ngzarr::Examplesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'examples.orchestration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024dev.angzarr.examplesP\001Z)github.com/angzarr/angzarr/proto/examples\252\002\020Angzarr.Examples\352\002\021Angzarr::Examples'
  _globals['_BUYINPHASE']._serialized_start=244
  _globals['_BUYINPHASE']._serialized_end=414
  _globals['_REGISTRATIONPHASE']._serialized_start=417
  _globals['_REGISTRATIONPHASE']._serialized_end=638
  _globals['_REBUYPHASE']._serialized_start=641
  _globals['_REBUYPHASE']._serialized_end=830
  _globals['_ORCHESTRATIONFAILURE']._serialized_start=76
  _globals['_ORCHESTRATIONFAILURE']._serialized_end=241
# @@protoc_insertion_point(module_scope)
