# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: angzarr/upcaster.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'angzarr/upcaster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.angzarr import types_pb2 as angzarr_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ngzarr/upcaster.proto\x12\x07\x61ngzarr\x1a\x13\x61ngzarr/types.proto\"S\n\rUpcastRequest\x12\x16\n\x06\x64omain\x18\x01 \x01(\tR\x06\x64omain\x12*\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x12.angzarr.EventPageR\x06\x65vents\"<\n\x0eUpcastResponse\x12*\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x12.angzarr.EventPageR\x06\x65vents2L\n\x0fUpcasterService\x12\x39\n\x06Upcast\x12\x16.angzarr.UpcastRequest\x1a\x17.angzarr.UpcastResponseBM\n\x0b\x64\x65v.angzarrP\x01Z(github.com/angzarr/angzarr/proto/angzarr\xaa\x02\x07\x41ngzarr\xea\x02\x07\x41ngzarrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'angzarr.upcaster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013dev.angzarrP\001Z(github.com/angzarr/angzarr/proto/angzarr\252\002\007Angzarr\352\002\007Angzarr'
  _globals['_UPCASTREQUEST']._serialized_start=56
  _globals['_UPCASTREQUEST']._serialized_end=139
  _globals['_UPCASTRESPONSE']._serialized_start=141
  _globals['_UPCASTRESPONSE']._serialized_end=201
  _globals['_UPCASTERSERVICE']._serialized_start=203
  _globals['_UPCASTERSERVICE']._serialized_end=279
# @@protoc_insertion_point(module_scope)
