# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: angzarr/saga.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'angzarr/saga.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.angzarr import types_pb2 as angzarr_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from angzarr_client.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61ngzarr/saga.proto\x12\x07\x61ngzarr\x1a\x13\x61ngzarr/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\"\xb8\x01\n\x11SagaHandleRequest\x12*\n\x06source\x18\x01 \x01(\x0b\x32\x12.angzarr.EventBookR\x06source\x12.\n\tsync_mode\x18\x02 \x01(\x0e\x32\x11.angzarr.SyncModeR\x08syncMode\x12G\n\x12\x63\x61scade_error_mode\x18\x03 \x01(\x0e\x32\x19.angzarr.CascadeErrorModeR\x10\x63\x61scadeErrorMode\"L\n\x14SpeculateSagaRequest\x12\x34\n\x07request\x18\x01 \x01(\x0b\x32\x1a.angzarr.SagaHandleRequestR\x07request\"l\n\x0cSagaResponse\x12\x30\n\x08\x63ommands\x18\x01 \x03(\x0b\x32\x14.angzarr.CommandBookR\x08\x63ommands\x12*\n\x06\x65vents\x18\x02 \x03(\x0b\x32\x12.angzarr.EventBookR\x06\x65vents\"\x9d\x03\n\x16SagaCompensationFailed\x12\x41\n\x14triggering_aggregate\x18\x01 \x01(\x0b\x32\x0e.angzarr.CoverR\x13triggeringAggregate\x12:\n\x19triggering_event_sequence\x18\x02 \x01(\rR\x17triggeringEventSequence\x12\x1b\n\tsaga_name\x18\x03 \x01(\tR\x08sagaName\x12)\n\x10rejection_reason\x18\x04 \x01(\tR\x0frejectionReason\x12>\n\x1b\x63ompensation_failure_reason\x18\x05 \x01(\tR\x19\x63ompensationFailureReason\x12?\n\x10rejected_command\x18\x06 \x01(\x0b\x32\x14.angzarr.CommandBookR\x0frejectedCommand\x12;\n\x0boccurred_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt2J\n\x0bSagaService\x12;\n\x06Handle\x12\x1a.angzarr.SagaHandleRequest\x1a\x15.angzarr.SagaResponse2\xe8\x01\n\x16SagaCoordinatorService\x12Y\n\x07\x45xecute\x12\x1a.angzarr.SagaHandleRequest\x1a\x15.angzarr.SagaResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/saga/execute:\x01*\x12s\n\x12\x45xecuteSpeculative\x12\x1d.angzarr.SpeculateSagaRequest\x1a\x15.angzarr.SagaResponse\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v1/saga/execute/speculative:\x01*BM\n\x0b\x64\x65v.angzarrP\x01Z(github.com/angzarr/angzarr/proto/angzarr\xaa\x02\x07\x41ngzarr\xea\x02\x07\x41ngzarrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'angzarr.saga_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013dev.angzarrP\001Z(github.com/angzarr/angzarr/proto/angzarr\252\002\007Angzarr\352\002\007Angzarr'
  _globals['_SAGACOORDINATORSERVICE'].methods_by_name['Execute']._loaded_options = None
  _globals['_SAGACOORDINATORSERVICE'].methods_by_name['Execute']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/saga/execute:\001*'
  _globals['_SAGACOORDINATORSERVICE'].methods_by_name['ExecuteSpeculative']._loaded_options = None
  _globals['_SAGACOORDINATORSERVICE'].methods_by_name['ExecuteSpeculative']._serialized_options = b'\202\323\344\223\002!\"\034/v1/saga/execute/speculative:\001*'
  _globals['_SAGAHANDLEREQUEST']._serialized_start=116
  _globals['_SAGAHANDLEREQUEST']._serialized_end=300
  _globals['_SPECULATESAGAREQUEST']._serialized_start=302
  _globals['_SPECULATESAGAREQUEST']._serialized_end=378
  _globals['_SAGARESPONSE']._serialized_start=380
  _globals['_SAGARESPONSE']._serialized_end=488
  _globals['_SAGACOMPENSATIONFAILED']._serialized_start=491
  _globals['_SAGACOMPENSATIONFAILED']._serialized_end=904
  _globals['_SAGASERVICE']._serialized_start=906
  _globals['_SAGASERVICE']._serialized_end=980
  _globals['_SAGACOORDINATORSERVICE']._serialized_start=983
  _globals['_SAGACOORDINATORSERVICE']._serialized_end=1215
# @@protoc_insertion_point(module_scope)
