# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: examples/poker_types.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'examples/poker_types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x65xamples/poker_types.proto\x12\x08\x65xamples\"N\n\x04\x43\x61rd\x12\"\n\x04suit\x18\x01 \x01(\x0e\x32\x0e.examples.SuitR\x04suit\x12\"\n\x04rank\x18\x02 \x01(\x0e\x32\x0e.examples.RankR\x04rank\"\x82\x01\n\x0bHandRanking\x12\x33\n\trank_type\x18\x01 \x01(\x0e\x32\x16.examples.HandRankTypeR\x08rankType\x12(\n\x07kickers\x18\x02 \x03(\x0e\x32\x0e.examples.RankR\x07kickers\x12\x14\n\x05score\x18\x03 \x01(\x05R\x05score\"G\n\x08\x43urrency\x12\x16\n\x06\x61mount\x18\x01 \x01(\x03R\x06\x61mount\x12#\n\rcurrency_code\x18\x02 \x01(\tR\x0c\x63urrencyCode\"\xb0\x01\n\x04Seat\x12\x1a\n\x08position\x18\x01 \x01(\x05R\x08position\x12\x1f\n\x0bplayer_root\x18\x02 \x01(\x0cR\nplayerRoot\x12(\n\x05stack\x18\x03 \x01(\x0b\x32\x12.examples.CurrencyR\x05stack\x12\x1b\n\tis_active\x18\x04 \x01(\x08R\x08isActive\x12$\n\x0eis_sitting_out\x18\x05 \x01(\x08R\x0cisSittingOut\"c\n\x03Pot\x12\x16\n\x06\x61mount\x18\x01 \x01(\x03R\x06\x61mount\x12)\n\x10\x65ligible_players\x18\x02 \x03(\x0cR\x0f\x65ligiblePlayers\x12\x19\n\x08pot_type\x18\x03 \x01(\tR\x07potType*M\n\x04Suit\x12\x14\n\x10SUIT_UNSPECIFIED\x10\x00\x12\t\n\x05\x43LUBS\x10\x01\x12\x0c\n\x08\x44IAMONDS\x10\x02\x12\n\n\x06HEARTS\x10\x03\x12\n\n\x06SPADES\x10\x04*\x9e\x01\n\x04Rank\x12\x14\n\x10RANK_UNSPECIFIED\x10\x00\x12\x07\n\x03TWO\x10\x02\x12\t\n\x05THREE\x10\x03\x12\x08\n\x04\x46OUR\x10\x04\x12\x08\n\x04\x46IVE\x10\x05\x12\x07\n\x03SIX\x10\x06\x12\t\n\x05SEVEN\x10\x07\x12\t\n\x05\x45IGHT\x10\x08\x12\x08\n\x04NINE\x10\t\x12\x07\n\x03TEN\x10\n\x12\x08\n\x04JACK\x10\x0b\x12\t\n\x05QUEEN\x10\x0c\x12\x08\n\x04KING\x10\r\x12\x07\n\x03\x41\x43\x45\x10\x0e*\xc7\x01\n\x0cHandRankType\x12\x19\n\x15HAND_RANK_UNSPECIFIED\x10\x00\x12\r\n\tHIGH_CARD\x10\x01\x12\x08\n\x04PAIR\x10\x02\x12\x0c\n\x08TWO_PAIR\x10\x03\x12\x13\n\x0fTHREE_OF_A_KIND\x10\x04\x12\x0c\n\x08STRAIGHT\x10\x05\x12\t\n\x05\x46LUSH\x10\x06\x12\x0e\n\nFULL_HOUSE\x10\x07\x12\x12\n\x0e\x46OUR_OF_A_KIND\x10\x08\x12\x12\n\x0eSTRAIGHT_FLUSH\x10\t\x12\x0f\n\x0bROYAL_FLUSH\x10\n*q\n\x0bGameVariant\x12\x1c\n\x18GAME_VARIANT_UNSPECIFIED\x10\x00\x12\x10\n\x0cTEXAS_HOLDEM\x10\x01\x12\t\n\x05OMAHA\x10\x02\x12\x12\n\x0e\x46IVE_CARD_DRAW\x10\x03\x12\x13\n\x0fSEVEN_CARD_STUD\x10\x04*q\n\x0c\x42\x65ttingPhase\x12\x1d\n\x19\x42\x45TTING_PHASE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PREFLOP\x10\x01\x12\x08\n\x04\x46LOP\x10\x02\x12\x08\n\x04TURN\x10\x03\x12\t\n\x05RIVER\x10\x04\x12\x08\n\x04\x44RAW\x10\x05\x12\x0c\n\x08SHOWDOWN\x10\x06*c\n\nActionType\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x08\n\x04\x46OLD\x10\x01\x12\t\n\x05\x43HECK\x10\x02\x12\x08\n\x04\x43\x41LL\x10\x03\x12\x07\n\x03\x42\x45T\x10\x04\x12\t\n\x05RAISE\x10\x05\x12\n\n\x06\x41LL_IN\x10\x06*<\n\nPlayerType\x12\x1b\n\x17PLAYER_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05HUMAN\x10\x01\x12\x06\n\x02\x41I\x10\x02\x42j\n\x14\x64\x65v.angzarr.examplesP\x01Z)github.com/angzarr/angzarr/proto/examples\xaa\x02\x10\x41ngzarr.Examples\xea\x02\x11\x41ngzarr::Examplesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'examples.poker_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024dev.angzarr.examplesP\001Z)github.com/angzarr/angzarr/proto/examples\252\002\020Angzarr.Examples\352\002\021Angzarr::Examples'
  _globals['_SUIT']._serialized_start=606
  _globals['_SUIT']._serialized_end=683
  _globals['_RANK']._serialized_start=686
  _globals['_RANK']._serialized_end=844
  _globals['_HANDRANKTYPE']._serialized_start=847
  _globals['_HANDRANKTYPE']._serialized_end=1046
  _globals['_GAMEVARIANT']._serialized_start=1048
  _globals['_GAMEVARIANT']._serialized_end=1161
  _globals['_BETTINGPHASE']._serialized_start=1163
  _globals['_BETTINGPHASE']._serialized_end=1276
  _globals['_ACTIONTYPE']._serialized_start=1278
  _globals['_ACTIONTYPE']._serialized_end=1377
  _globals['_PLAYERTYPE']._serialized_start=1379
  _globals['_PLAYERTYPE']._serialized_end=1439
  _globals['_CARD']._serialized_start=40
  _globals['_CARD']._serialized_end=118
  _globals['_HANDRANKING']._serialized_start=121
  _globals['_HANDRANKING']._serialized_end=251
  _globals['_CURRENCY']._serialized_start=253
  _globals['_CURRENCY']._serialized_end=324
  _globals['_SEAT']._serialized_start=327
  _globals['_SEAT']._serialized_end=503
  _globals['_POT']._serialized_start=505
  _globals['_POT']._serialized_end=604
# @@protoc_insertion_point(module_scope)
