# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: examples/rebuy.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'examples/rebuy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.examples import orchestration_pb2 as examples_dot_orchestration__pb2
from angzarr_client.proto.examples import poker_types_pb2 as examples_dot_poker__types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x65xamples/rebuy.proto\x12\x08\x65xamples\x1a\x1c\x65xamples/orchestration.proto\x1a\x1a\x65xamples/poker_types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\rInitiateRebuy\x12\'\n\x0ftournament_root\x18\x01 \x01(\x0cR\x0etournamentRoot\x12\x1d\n\ntable_root\x18\x02 \x01(\x0cR\ttableRoot\x12\x12\n\x04seat\x18\x03 \x01(\x05R\x04seat\"8\n\x0f\x43onfirmRebuyFee\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\"P\n\x0fReleaseRebuyFee\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\"\x83\x01\n\rAddRebuyChips\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\x12\x12\n\x04seat\x18\x03 \x01(\x05R\x04seat\x12\x16\n\x06\x61mount\x18\x04 \x01(\x03R\x06\x61mount\"\xf8\x01\n\x0eRebuyRequested\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\'\n\x0ftournament_root\x18\x02 \x01(\x0cR\x0etournamentRoot\x12\x1d\n\ntable_root\x18\x03 \x01(\x0cR\ttableRoot\x12\x12\n\x04seat\x18\x04 \x01(\x05R\x04seat\x12$\n\x03\x66\x65\x65\x18\x05 \x01(\x0b\x32\x12.examples.CurrencyR\x03\x66\x65\x65\x12=\n\x0crequested_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0brequestedAt\"\xe9\x01\n\x11RebuyFeeConfirmed\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\'\n\x0ftournament_root\x18\x02 \x01(\x0cR\x0etournamentRoot\x12$\n\x03\x66\x65\x65\x18\x03 \x01(\x0b\x32\x12.examples.CurrencyR\x03\x66\x65\x65\x12\x1f\n\x0b\x63hips_added\x18\x04 \x01(\x03R\nchipsAdded\x12=\n\x0c\x63onfirmed_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63onfirmedAt\"\x8e\x01\n\x10RebuyFeeReleased\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x16\n\x06reason\x18\x02 \x01(\tR\x06reason\x12;\n\x0breleased_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nreleasedAt\"\xd9\x01\n\x0fRebuyChipsAdded\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12%\n\x0ereservation_id\x18\x02 \x01(\x0cR\rreservationId\x12\x12\n\x04seat\x18\x03 \x01(\x05R\x04seat\x12\x16\n\x06\x61mount\x18\x04 \x01(\x03R\x06\x61mount\x12\x1b\n\tnew_stack\x18\x05 \x01(\x03R\x08newStack\x12\x35\n\x08\x61\x64\x64\x65\x64_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x61\x64\x64\x65\x64\x41t\"\xe7\x02\n\x0eRebuyInitiated\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\'\n\x0ftournament_root\x18\x02 \x01(\x0cR\x0etournamentRoot\x12\x1d\n\ntable_root\x18\x03 \x01(\x0cR\ttableRoot\x12%\n\x0ereservation_id\x18\x04 \x01(\x0cR\rreservationId\x12\x12\n\x04seat\x18\x05 \x01(\x05R\x04seat\x12$\n\x03\x66\x65\x65\x18\x06 \x01(\x0b\x32\x12.examples.CurrencyR\x03\x66\x65\x65\x12 \n\x0c\x63hips_to_add\x18\x07 \x01(\x03R\nchipsToAdd\x12*\n\x05phase\x18\x08 \x01(\x0e\x32\x14.examples.RebuyPhaseR\x05phase\x12=\n\x0cinitiated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0binitiatedAt\"\xa6\x02\n\x0eRebuyCompleted\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\'\n\x0ftournament_root\x18\x02 \x01(\x0cR\x0etournamentRoot\x12\x1d\n\ntable_root\x18\x03 \x01(\x0cR\ttableRoot\x12%\n\x0ereservation_id\x18\x04 \x01(\x0cR\rreservationId\x12$\n\x03\x66\x65\x65\x18\x05 \x01(\x0b\x32\x12.examples.CurrencyR\x03\x66\x65\x65\x12\x1f\n\x0b\x63hips_added\x18\x06 \x01(\x03R\nchipsAdded\x12=\n\x0c\x63ompleted_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63ompletedAt\"\xb8\x01\n\x0bRebuyFailed\x12\x1f\n\x0bplayer_root\x18\x01 \x01(\x0cR\nplayerRoot\x12\'\n\x0ftournament_root\x18\x02 \x01(\x0cR\x0etournamentRoot\x12%\n\x0ereservation_id\x18\x03 \x01(\x0cR\rreservationId\x12\x38\n\x07\x66\x61ilure\x18\x04 \x01(\x0b\x32\x1e.examples.OrchestrationFailureR\x07\x66\x61ilure\"\xdb\x01\n\x11RebuyPhaseChanged\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x33\n\nfrom_phase\x18\x02 \x01(\x0e\x32\x14.examples.RebuyPhaseR\tfromPhase\x12/\n\x08to_phase\x18\x03 \x01(\x0e\x32\x14.examples.RebuyPhaseR\x07toPhase\x12\x39\n\nchanged_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tchangedAt\"\xd7\x02\n\x16RebuyOrchestratorState\x12%\n\x0ereservation_id\x18\x01 \x01(\x0cR\rreservationId\x12\x1f\n\x0bplayer_root\x18\x02 \x01(\x0cR\nplayerRoot\x12\'\n\x0ftournament_root\x18\x03 \x01(\x0cR\x0etournamentRoot\x12\x1d\n\ntable_root\x18\x04 \x01(\x0cR\ttableRoot\x12\x12\n\x04seat\x18\x05 \x01(\x05R\x04seat\x12\x10\n\x03\x66\x65\x65\x18\x06 \x01(\x03R\x03\x66\x65\x65\x12 \n\x0c\x63hips_to_add\x18\x07 \x01(\x03R\nchipsToAdd\x12*\n\x05phase\x18\x08 \x01(\x0e\x32\x14.examples.RebuyPhaseR\x05phase\x12\x39\n\nstarted_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartedAtBj\n\x14\x64\x65v.angzarr.examplesP\x01Z)github.com/angzarr/angzarr/proto/examples\xaa\x02\x10\x41ngzarr.Examples\xea\x02\x11\x41ngzarr::Examplesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'examples.rebuy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024dev.angzarr.examplesP\001Z)github.com/angzarr/angzarr/proto/examples\252\002\020Angzarr.Examples\352\002\021Angzarr::Examples'
  _globals['_INITIATEREBUY']._serialized_start=125
  _globals['_INITIATEREBUY']._serialized_end=232
  _globals['_CONFIRMREBUYFEE']._serialized_start=234
  _globals['_CONFIRMREBUYFEE']._serialized_end=290
  _globals['_RELEASEREBUYFEE']._serialized_start=292
  _globals['_RELEASEREBUYFEE']._serialized_end=372
  _globals['_ADDREBUYCHIPS']._serialized_start=375
  _globals['_ADDREBUYCHIPS']._serialized_end=506
  _globals['_REBUYREQUESTED']._serialized_start=509
  _globals['_REBUYREQUESTED']._serialized_end=757
  _globals['_REBUYFEECONFIRMED']._serialized_start=760
  _globals['_REBUYFEECONFIRMED']._serialized_end=993
  _globals['_REBUYFEERELEASED']._serialized_start=996
  _globals['_REBUYFEERELEASED']._serialized_end=1138
  _globals['_REBUYCHIPSADDED']._serialized_start=1141
  _globals['_REBUYCHIPSADDED']._serialized_end=1358
  _globals['_REBUYINITIATED']._serialized_start=1361
  _globals['_REBUYINITIATED']._serialized_end=1720
  _globals['_REBUYCOMPLETED']._serialized_start=1723
  _globals['_REBUYCOMPLETED']._serialized_end=2017
  _globals['_REBUYFAILED']._serialized_start=2020
  _globals['_REBUYFAILED']._serialized_end=2204
  _globals['_REBUYPHASECHANGED']._serialized_start=2207
  _globals['_REBUYPHASECHANGED']._serialized_end=2426
  _globals['_REBUYORCHESTRATORSTATE']._serialized_start=2429
  _globals['_REBUYORCHESTRATORSTATE']._serialized_end=2772
# @@protoc_insertion_point(module_scope)
