# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: angzarr/projector.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'angzarr/projector.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from angzarr_client.proto.angzarr import types_pb2 as angzarr_dot_types__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from angzarr_client.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ngzarr/projector.proto\x12\x07\x61ngzarr\x1a\x13\x61ngzarr/types.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\"G\n\x19SpeculateProjectorRequest\x12*\n\x06\x65vents\x18\x01 \x01(\x0b\x32\x12.angzarr.EventBookR\x06\x65vents2\x83\x01\n\x10ProjectorService\x12\x31\n\x06Handle\x12\x12.angzarr.EventBook\x1a\x13.angzarr.Projection\x12<\n\x11HandleSpeculative\x12\x12.angzarr.EventBook\x1a\x13.angzarr.Projection2\xba\x02\n\x1bProjectorCoordinatorService\x12W\n\nHandleSync\x12\x15.angzarr.EventRequest\x1a\x13.angzarr.Projection\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/projector/sync:\x01*\x12N\n\x06Handle\x12\x12.angzarr.EventBook\x1a\x16.google.protobuf.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/projector:\x01*\x12r\n\x11HandleSpeculative\x12\".angzarr.SpeculateProjectorRequest\x1a\x13.angzarr.Projection\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/projector/speculative:\x01*BM\n\x0b\x64\x65v.angzarrP\x01Z(github.com/angzarr/angzarr/proto/angzarr\xaa\x02\x07\x41ngzarr\xea\x02\x07\x41ngzarrb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'angzarr.projector_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\013dev.angzarrP\001Z(github.com/angzarr/angzarr/proto/angzarr\252\002\007Angzarr\352\002\007Angzarr'
  _globals['_PROJECTORCOORDINATORSERVICE'].methods_by_name['HandleSync']._loaded_options = None
  _globals['_PROJECTORCOORDINATORSERVICE'].methods_by_name['HandleSync']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/projector/sync:\001*'
  _globals['_PROJECTORCOORDINATORSERVICE'].methods_by_name['Handle']._loaded_options = None
  _globals['_PROJECTORCOORDINATORSERVICE'].methods_by_name['Handle']._serialized_options = b'\202\323\344\223\002\022\"\r/v1/projector:\001*'
  _globals['_PROJECTORCOORDINATORSERVICE'].methods_by_name['HandleSpeculative']._loaded_options = None
  _globals['_PROJECTORCOORDINATORSERVICE'].methods_by_name['HandleSpeculative']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/projector/speculative:\001*'
  _globals['_SPECULATEPROJECTORREQUEST']._serialized_start=116
  _globals['_SPECULATEPROJECTORREQUEST']._serialized_end=187
  _globals['_PROJECTORSERVICE']._serialized_start=190
  _globals['_PROJECTORSERVICE']._serialized_end=321
  _globals['_PROJECTORCOORDINATORSERVICE']._serialized_start=324
  _globals['_PROJECTORCOORDINATORSERVICE']._serialized_end=638
# @@protoc_insertion_point(module_scope)
